@@ -21,3 +21,9 @@ class Message(object):
 
     def get_json(self):
         return json.dumps(self.get_dict())
+
+def from_dict(dic):
+    return Message(dic["method"], dic["topic"], dic["status"], dic["body"])
+
+def from_json(js):
+    return from_dict(json.loads(js))
